@@ -1,12 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from blueflask.lib.decorators import auth as ldap
-
 from . import api
 
 
 @api.route('/simboxes', methods=['PUT'])
-@ldap.login_required
 def manage_simbox():
     """
     Block or unblock a simbox using its IMSI or its ISDN.
