@@ -1,19 +1,16 @@
-#!/usr/bin/env python
-# encoding: utf-8
-
+# -*- coding: utf-8 -*-
 
 from to_log import Logger
 
 import configparser
 import socket
 
-import redis
-
 
 __all__ = [
+    'ADDRESS',
+    'APIGW',
     'CONFIG',
     'HOSTNAME',
-    'API_REGISTRY',
     'LOGS',
     'SERVICE_CODE'
     ]
@@ -24,9 +21,15 @@ CONFIG.read('/etc/hlr-services/hlr-services.conf')
 
 SERVICE_CODE = CONFIG['APP']['service_code']
 HOSTNAME = socket.gethostname().split('.')[0]
-API_REGISTRY = redis.Redis(db=15)
-if HOSTNAME.startswith('blpr'):
-    API_REGISTRY = redis.Redis(host='api.blueline.mg', db=15)
+_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+_socket.connect(("41.204.103.205", 80))
+ADDRESS = _socket.getsockname()[0]
+if HOSTNAME.startswith('bldv'):
+    APIGW = 'bldv040v.blueline.mg'
+elif HOSTNAME.startswith('blst'):
+    APIGW = 'blst040v.blueline.mg'
+else:
+    APIGW = 'api.blueline.mg'
 
 LOG_LEVEL = CONFIG['LOGS']['level']
 LOG_FILE = CONFIG['LOGS']['filename']
